import { Generated, Insertable, Selectable, Updateable } from 'kysely'

// 商品表
export interface MenuCommodityTable {
  id: Generated<number> // 主键
  type: string // 商品类型
  merchant_id: number // 商户ID
  store_id: number // 店铺ID
  name: string // 商品名称
  cate_id: number // 分类ID
  goods_no: string // 商品编号
  is_single_spec: 'Y' | 'N' // 是否单规格 (Y-Yes, N-No)
  logo: string // 商品Logo
  images: string // 商品图片
  price: number // 价格
  line_price: number // 划线价
  stock: number // 库存
  weight: number // 重量
  coupon_ids: string // 优惠券ID
  service_time: number // 服务时间
  init_sale: number // 初始销量
  sale_point: string // 卖点
  can_use_point: 'Y' | 'N' // 是否可用积分 (Y-Yes, N-No)
  is_member_discount: 'Y' | 'N' // 是否会员折扣 (Y-Yes, N-No)
  sort: number // 排序
  description?: string // 商品描述
  create_time?: string // 创建时间
  update_time?: string // 更新时间
  operator?: string // 操作员
  status: 'A' | 'D' // 状态 (A-Active, D-Deleted)
}

export type MenuCommodity = Selectable<MenuCommodityTable>
export type NewMenuCommodity = Insertable<MenuCommodityTable>
export type MenuCommodityUpdate = Updateable<MenuCommodityTable>
